@@ -5,14 +5,6 @@
     $Id: body.cxx,v 1.3 2008-10-07 11:06:25 tat Exp $
  ***************************************************************************/
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
 #include <mimetic/mimeentity.h>
 #include <mimetic/body.h>
 
@@ -50,6 +42,7 @@ bool Body::load(const string& fqn)
     File in(fqn);
     if(!in)
         return false;
+    this->clear();
     File::iterator beg = in.begin(), end = in.end();
     std::copy(beg, end, back_inserter(*this) );
     return true;
