@@ -6,7 +6,7 @@ namespace mimetic
 using namespace std;
 struct test_item
 {
-    char *input, *field, *value;
+    const char *input, *field, *value;
 };
 
 static test_item testData[] = { 
