@@ -12,7 +12,7 @@ struct TEST_CLASS( testStrUtils  )
 {
     void TEST_FUNCTION( test_remove_external_blanks )
     {
-        struct test_item { char *in, *out; };
+        struct test_item { const char *in, *out; };
         test_item data[] = { 
                 { "", "" },
                 { "a", "a" },
