@@ -12,9 +12,9 @@ template<int sz>
 struct test_item
 {
     enum { part_count = sz };
-    char *input;
-    char *delims;
-    char *part[sz];
+    const char *input;
+    const char *delims;
+    const char *part[sz];
 };
 
 class TEST_CLASS( test_tokenizer )
